@@ -1,18 +1,22 @@
-# Copyright (C) 2010 Richard Lincoln
+# Copyright (C) 2010-2011 Richard Lincoln
 #
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation; either
-# version 2.1 of the License, or (at your option) any later version.
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to
+# deal in the Software without restriction, including without limitation the
+# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+# sell copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 #
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
 #
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA, USA
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
+# IN THE SOFTWARE.
 
 from CIM14.IEC61970.Core.IdentifiedObject import IdentifiedObject
 
@@ -25,7 +29,7 @@ class ReadingType(IdentifiedObject):
 
         @param multiplier: Multiplier for 'unit'. Values are: "k", "d", "n", "M", "none", "G", "micro", "T", "c", "m", "p"
         @param kind: Kind of reading. Values are: "voltageAngle", "current", "time", "powerFactor", "voltage", "frequency", "power", "other", "energy", "demand", "volume", "date", "phaseAngle", "pressure", "currentAngle"
-        @param unit: Unit for the reading value. Values are: "N", "VArh", "VA", "none", "m3", "kg/J", "deg", "W/Hz", "g", "Wh", "W/s", "Pa", "V/VAr", "ohm", "h", "F", "H", "m2", "VAr", "A", "rad", "s", "S", "VAh", "Hz", "oC", "s-1", "min", "J", "Hz-1", "J/s", "m", "W", "V"
+        @param unit: Unit for the reading value. Values are: "N", "VArh", "VA", "none", "m3", "kg/J", "deg", "W/Hz", "g", "Wh", "W/s", "Pa", "V/VAr", "ohm", "h", "F", "H", "m2", "VAr", "A", "rad", "s", "S", "VAh", "Hz", "degC", "s-1", "min", "J", "Hz-1", "J/s", "m", "W", "V"
         @param reverseChronology: True for systems that must operate in 'reverse' chronological order. 
         @param defaultQuality: Characteristics of a data value conveyed by a specific Reading, which allow an application to understand how a specific Reading is to be interpreted. 
         @param defaultValueDataType: Numeric type to be expected for the associated IntervalBlock.value (e.g. unsignedInteger). 
@@ -43,7 +47,7 @@ class ReadingType(IdentifiedObject):
         #: Kind of reading. Values are: "voltageAngle", "current", "time", "powerFactor", "voltage", "frequency", "power", "other", "energy", "demand", "volume", "date", "phaseAngle", "pressure", "currentAngle"
         self.kind = kind
 
-        #: Unit for the reading value. Values are: "N", "VArh", "VA", "none", "m3", "kg/J", "deg", "W/Hz", "g", "Wh", "W/s", "Pa", "V/VAr", "ohm", "h", "F", "H", "m2", "VAr", "A", "rad", "s", "S", "VAh", "Hz", "oC", "s-1", "min", "J", "Hz-1", "J/s", "m", "W", "V"
+        #: Unit for the reading value. Values are: "N", "VArh", "VA", "none", "m3", "kg/J", "deg", "W/Hz", "g", "Wh", "W/s", "Pa", "V/VAr", "ohm", "h", "F", "H", "m2", "VAr", "A", "rad", "s", "S", "VAh", "Hz", "degC", "s-1", "min", "J", "Hz-1", "J/s", "m", "W", "V"
         self.unit = unit
 
         #: True for systems that must operate in 'reverse' chronological order.
@@ -91,7 +95,7 @@ class ReadingType(IdentifiedObject):
 
     def setReadings(self, value):
         for x in self._Readings:
-            x._ReadingType = None
+            x.ReadingType = None
         for y in value:
             y._ReadingType = self
         self._Readings = value
@@ -100,13 +104,11 @@ class ReadingType(IdentifiedObject):
 
     def addReadings(self, *Readings):
         for obj in Readings:
-            obj._ReadingType = self
-            self._Readings.append(obj)
+            obj.ReadingType = self
 
     def removeReadings(self, *Readings):
         for obj in Readings:
-            obj._ReadingType = None
-            self._Readings.remove(obj)
+            obj.ReadingType = None
 
     # Demand configuration.
     dynamicConfiguration = None
@@ -118,7 +120,7 @@ class ReadingType(IdentifiedObject):
 
     def setIntervalBlocks(self, value):
         for x in self._IntervalBlocks:
-            x._ReadingType = None
+            x.ReadingType = None
         for y in value:
             y._ReadingType = self
         self._IntervalBlocks = value
@@ -127,13 +129,11 @@ class ReadingType(IdentifiedObject):
 
     def addIntervalBlocks(self, *IntervalBlocks):
         for obj in IntervalBlocks:
-            obj._ReadingType = self
-            self._IntervalBlocks.append(obj)
+            obj.ReadingType = self
 
     def removeIntervalBlocks(self, *IntervalBlocks):
         for obj in IntervalBlocks:
-            obj._ReadingType = None
-            self._IntervalBlocks.remove(obj)
+            obj.ReadingType = None
 
     def getPending(self):
         """Pending conversion that produced this reading type.
@@ -146,6 +146,7 @@ class ReadingType(IdentifiedObject):
 
         self._Pending = value
         if self._Pending is not None:
+            self._Pending.ReadingType = None
             self._Pending._ReadingType = self
 
     Pending = property(getPending, setPending)
@@ -161,6 +162,7 @@ class ReadingType(IdentifiedObject):
 
         self._Register = value
         if self._Register is not None:
+            self._Register.ReadingType = None
             self._Register._ReadingType = self
 
     Register = property(getRegister, setRegister)
